@@ -2,12 +2,18 @@ from neomodel.exception import InflateError, DeflateError
 from datetime import datetime, date
 import time
 import pytz
+import json
+import sys
+
+if sys.version_info >= (3, 0):
+    unicode = lambda x: str(x)
 
 
 def validator(fn):
-    if fn.func_name is 'inflate':
+    fn_name = fn.func_name if hasattr(fn, 'func_name') else fn.__name__
+    if fn_name is 'inflate':
         exc_class = InflateError
-    elif fn.func_name == 'deflate':
+    elif fn_name == 'deflate':
         exc_class = DeflateError
     else:
         raise Exception("Unknown Property method " + fn.func_name)
@@ -114,11 +120,19 @@ class DateTimeProperty(Property):
     def deflate(self, value):
         if not isinstance(value, datetime):
             raise ValueError('datetime object expected, got {0}'.format(value))
-        if not value.tzinfo:
-            raise ValueError('datetime object {0} must have a timezone'.format(value))
         return time.mktime(value.utctimetuple())
 
 
+class JSONProperty(Property):
+    @validator
+    def inflate(self, value):
+        return json.loads(value)
+
+    @validator
+    def deflate(self, value):
+        return json.dumps(value)
+
+
 class AliasProperty(property, Property):
     def __init__(self, to=None):
         self.target = to
