@@ -20,8 +20,9 @@ def exec_hook(hook_name, self, *args, **kwargs):
 
 def hooks(fn):
     def hooked(self, *args, **kwargs):
-        exec_hook('pre_' + fn.func_name, self, *args, **kwargs)
+        fn_name = fn.func_name if hasattr(fn, 'func_name') else fn.__name__
+        exec_hook('pre_' + fn_name, self, *args, **kwargs)
         val = fn(self, *args, **kwargs)
-        exec_hook('post_' + fn.func_name, self, *args, **kwargs)
+        exec_hook('post_' + fn_name, self, *args, **kwargs)
         return val
     return hooked
